import { useModel } from 'umi';
import { confirm } from '@/components/AModal';
import OssImage from '@/components/OssImage';
import SvgIcon from '@/components/SvgIcon';
import { logout } from '@/services/user';
import { RightOutlined, QuestionOutlined } from '@ant-design/icons';
import { Button, Popover, Modal } from 'antd';
import classNames from 'classnames';
import React, { CSSProperties } from 'react';
import { useCallback } from 'react';
import { useState } from 'react';
import styles from './UserCenter.less';
import defaultAvatorImg from '@/assets/avator_default.svg';
import FolderSetModal from './FolderSetModal';
import storage from '@/utils/storage';
import { isClient } from '@/utils/tool';

interface UserCenterProps {
  className?: string;
  style?: CSSProperties;
}

export default function UserCenter(props: UserCenterProps) {
  const { className } = props;
  const [popVisible, setPopVisible] = useState(false);

  const onVisibleChange = useCallback((nextVisible) => {
    setPopVisible(nextVisible);
  }, []);

  const hidePop = useCallback(() => {
    setPopVisible(false);
  }, []);

  return (
    <Popover
      overlayClassName={styles.popWrapper}
      content={<PopContent hidePop={hidePop} />}
      trigger="click"
      visible={popVisible}
      onVisibleChange={onVisibleChange}
      placement="bottomRight"
      arrowContent={() => null}
    >
      <Button type="link" className={classNames(styles.btn, className)}>
        <SvgIcon
          className={classNames(styles.icon, popVisible ? styles.active : '')}
          xlinkHref="usercenter"
        />
      </Button>
    </Popover>
  );
}

interface PopContentProps {
  hidePop: () => void;
}

function PopContent(props: PopContentProps) {
  const { hidePop } = props;
  const {
    refresh,
    initialState: { currentUser } = {},
    setInitialState,
  } = useModel('@@initialState');
  const [folderSetModalVisible, setFolderSetModalVisbile] = useState(false);

  const tryLogout = useCallback(() => {
    if (hidePop) hidePop();
    // storage.remove('account');
    // storage.remove('password');
    confirm({
      onOk() {
        logout();
        refresh();
      },
      content: '确实退出登录?',
    });
  }, []);
  return (
    <div className={styles.popView}>
      <div className={styles.popHeader}>
        <div className={styles.left}>
          <div className={styles.name}>{currentUser?.cnName}</div>
          <div className={styles.phone}>{currentUser?.phone}</div>
        </div>
        <div className={styles.right}>
          <OssImage
            className={styles.avator}
            src={currentUser?.headImgUrl}
            preview={false}
            fallback={defaultAvatorImg}
          />
        </div>
      </div>
      <div className={styles.popContent}>
        {/* <div className={styles.listGroupTitle}><div>账号</div></div> */}
        {/* <div className={styles.listItem}>
          <span>账号设置</span>
          <RightOutlined color="#8E909F" />
        </div> */}
        {isClient ? (
          <div
            className={styles.listItem}
            onClick={() => {
              setFolderSetModalVisbile(true);
              hidePop();
            }}
          >
            <span>同步设置</span>
            <RightOutlined color="#8E909F" />
          </div>
        ) : null}
        {/* <div className={styles.listGroupTitle}><div>其他</div></div>
        <div className={styles.listItem}>
          <span>系统版本</span>
          <RightOutlined color="#8E909F" />
        </div>
        <div className={styles.listItem}>
          <span>关于易云</span>
          <RightOutlined color="#8E909F" />
        </div> */}
        <div className={styles.btnGroup}>
          <Button className={styles.logout} type="link" onClick={tryLogout}>
            退出登录
          </Button>
        </div>
      </div>
      {isClient ? (
        <FolderSetModal
          visible={folderSetModalVisible}
          onCancel={() => setFolderSetModalVisbile(false)}
        />
      ) : null}
    </div>
  );
}
