import React from 'react';
import { Modal, ModalProps, Table } from 'antd';
import { useModel, useRequest } from 'umi';
import { useState } from 'react';
import styles from './SyncModal.less';
import ATooltip from '../Tooltip';
import { fetchApi } from '@/utils/request';
import { firstCharToLowerCase, handleRequest } from '@/utils/tool';
import { useCallback } from 'react';
import system from '@/services/system';
import { useEffect } from 'react';
import storage from '@/utils/storage';

const columns = [
  {
    title: '文件夹名称',
    dataIndex: 'projName',
    width: 200,
    render: (text: string) => (
      <ATooltip title={text} placement="topLeft">
        {text}
      </ATooltip>
    ),
  },
  {
    title: '创建人',
    dataIndex: 'age',
    width: 88,
  },
  {
    title: '描述',
    dataIndex: 'notice',
    render: (text: string) => (
      <ATooltip title={text} placement="topLeft">
        {text}
      </ATooltip>
    ),
  },
];

interface DataType {
  key: React.Key;
  name: string;
  age: number;
  address: string;
}

interface SyncModalProps extends ModalProps {}

export default function SyncModal(props: SyncModalProps) {
  const { onOk: propsOnOk, onCancel: propsOnCancel, ...restProps } = props;
  const { initialState: { currentUser } = {} } = useModel('@@initialState');
  const [btnLoading, setBtnLoading] = useState(false);
  const [modalVisible, setModalVisible] = useState(restProps.visible || false);
  const [selectedKeys, setSelectedKeys] = useState<string[]>([]);
  const { loading, data, refresh } = useRequest(async () => {
    return await fetchApi('project/queryProjectListByUserId', {
      userId: currentUser!.id,
    });
  });

  const onOk = useCallback(
    async (e) => {
      setBtnLoading(true);
      const res = await system.syncProjects(selectedKeys);
      setBtnLoading(false);
      handleRequest(res!).success(() => {
        setModalVisible(false);
        storage.set('isNotFirstLogin', 'true', true);
        if (propsOnOk) {
          propsOnOk(e);
        }
      });
    },
    [selectedKeys, propsOnOk],
  );

  const onCancel = useCallback(
    (e) => {
      if (propsOnCancel) {
        propsOnCancel(e);
      }
      setModalVisible(false);
    },
    [propsOnCancel],
  );

  useEffect(() => {
    if (modalVisible || restProps.visible) {
      setSelectedKeys([]);
      refresh();
    }
  }, [modalVisible, restProps.visible, refresh]);

  return (
    <Modal
      title="同步文件夹至工作空间"
      visible={modalVisible}
      wrapClassName={styles.syncModal}
      cancelText="取消"
      okText="确定"
      width={540}
      maskClosable={false}
      onCancel={onCancel}
      okButtonProps={{
        disabled: selectedKeys.length === 0,
        loading: btnLoading,
      }}
      onOk={onOk}
      {...restProps}
    >
      <div className={styles.title}>
        选择「与我有关的文件夹」，并同步到「我的电脑/工作空间」中
      </div>
      <Table
        className={styles.table}
        rowKey="id"
        loading={loading}
        rowSelection={{
          type: 'checkbox',
          onChange: (
            selectedRowKeys: React.Key[],
            selectedRows: DataType[],
          ) => {
            // console.log(
            //   `selectedRowKeys: ${selectedRowKeys}`,
            //   'selectedRows: ',
            //   selectedRows,
            // );
            setSelectedKeys(selectedRowKeys as string[]);
          },
          selectedRowKeys: selectedKeys,
          // getCheckboxProps: (record: DataType) => ({
          //   disabled: record.name === 'Disabled User', // Column configuration not to be checked
          //   name: record.name,
          // }),
        }}
        pagination={false}
        columns={columns}
        dataSource={data || []}
        scroll={{ y: 200 }}
      />
    </Modal>
  );
}
