import React, { useState } from 'react';
import { Button, Input, InputProps, message } from 'antd';
import styles from './SmsInputer.less';
import { useCallback } from 'react';
import { throttle } from 'lodash';
import { handleRequest, isValidPhone } from '@/utils/tool';
import { useInterval } from 'ahooks';
import classNames from 'classnames';
import { fetchApi } from '@/utils/request';

interface SmsInputerProps extends InputProps {
  phone?: string;
}

export default function SmsInputer(props: SmsInputerProps) {
  const { phone, className, ...inpProps } = props;
  const [tickFlag, setTickFlag] = useState(false);
  const [timeNum, setTimeNum] = useState(59);
  // 发送验证码
  const sendCodeRequest = useCallback(
    throttle(async () => {
      if (tickFlag) return;
      if (!(phone && isValidPhone(phone))) {
        message.error('请先填写正确的手机号');
        return;
      }
      setTickFlag(true);
      // 调用发送验证码的接口
      const res = await fetchApi<null>('company/sendVerificationCode', {
        Phone: phone,
      });
      handleRequest(res).error(() => {
        message.error('验证码发送失败，请稍后再试');
        setTickFlag(false);
      });
    }),
    [phone],
  );

  useInterval(
    () => {
      if (timeNum === 0) {
        setTickFlag(false);
        setTimeNum(59);
        return;
      }
      setTimeNum((v) => v - 1);
    },
    tickFlag ? 1000 : null,
  );

  return (
    <div className={classNames(styles.smsInp, className)}>
      <Input className={styles.inp} {...inpProps} />
      <Button
        className={styles.btn}
        disabled={tickFlag}
        onClick={sendCodeRequest}
      >
        {tickFlag ? `重新获取 ${timeNum}` : '获取验证码'}
      </Button>
    </div>
  );
}
